@@ -6,10 +6,10 @@
 # WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
-# [🥭 Mango Markets](https://mango.markets/) support is available at:
-#   [Docs](https://docs.mango.markets/)
+# [🥭 Entropy Markets](https://entropy.markets/) support is available at:
+#   [Docs](https://docs.entropy.markets/)
 #   [Discord](https://discord.gg/67jySBhxrg)
-#   [Twitter](https://twitter.com/mangomarkets)
+#   [Twitter](https://twitter.com/entropymarkets)
 #   [Github](https://github.com/blockworks-foundation)
 #   [Email](mailto:hello@blockworks.foundation)
 
@@ -30,7 +30,7 @@ from .client import (
     TransactionMonitor,
     NullTransactionMonitor,
 )
-from .constants import MangoConstants
+from .constants import EntropyConstants
 from .context import Context
 from .idsjsonmarketlookup import IdsJsonMarketLookup
 from .instrumentlookup import (
@@ -110,7 +110,7 @@ class ContextBuilder:
         parser.add_argument(
             "--name",
             type=str,
-            default="Mango Explorer",
+            default="Entropy Explorer",
             help="Name of the program (used in reports and alerts)",
         )
         parser.add_argument(
@@ -125,16 +125,19 @@ class ContextBuilder:
             help="Solana RPC cluster URL (can be specified multiple times to provide failover when one errors; optional second parameter value defines websocket connection)",
         )
         parser.add_argument(
-            "--group-name", type=str, default=None, help="Mango group name"
+            "--group-name", type=str, default=None, help="Entropy group name"
         )
         parser.add_argument(
-            "--group-address", type=PublicKey, default=None, help="Mango group address"
-        )
-        parser.add_argument(
-            "--mango-program-address",
+            "--group-address",
             type=PublicKey,
             default=None,
-            help="Mango program address",
+            help="Entropy group address",
+        )
+        parser.add_argument(
+            "--entropy-program-address",
+            type=PublicKey,
+            default=None,
+            help="Entropy program address",
         )
         parser.add_argument(
             "--serum-program-address",
@@ -237,7 +240,9 @@ class ContextBuilder:
         ] = args.cluster_url
         group_name: typing.Optional[str] = args.group_name
         group_address: typing.Optional[PublicKey] = args.group_address
-        mango_program_address: typing.Optional[PublicKey] = args.mango_program_address
+        entropy_program_address: typing.Optional[
+            PublicKey
+        ] = args.entropy_program_address
         serum_program_address: typing.Optional[PublicKey] = args.serum_program_address
         skip_preflight: bool = bool(args.skip_preflight)
         tpu_retransmissions: int = int(args.tpu_retransmissions)
@@ -289,7 +294,7 @@ class ContextBuilder:
             actual_stale_data_pauses_before_retry,
             group_name,
             group_address,
-            mango_program_address,
+            entropy_program_address,
             serum_program_address,
             gma_chunk_size,
             gma_chunk_pause,
@@ -392,8 +397,8 @@ class ContextBuilder:
             return None
 
         # The first group is only used to determine the default cluster if it is not otherwise specified.
-        first_group_data = MangoConstants["groups"][0]
-        actual_name: str = name or os.environ.get("NAME") or "Mango Explorer"
+        first_group_data = EntropyConstants["groups"][0]
+        actual_name: str = name or os.environ.get("NAME") or "Entropy Explorer"
         actual_cluster: str = (
             cluster_name
             or os.environ.get("CLUSTER_NAME")
@@ -402,7 +407,7 @@ class ContextBuilder:
 
         # Now that we have the actual cluster name, taking environment variables and defaults into account,
         # we can decide what we want as the default group.
-        for group_data in MangoConstants["groups"]:
+        for group_data in EntropyConstants["groups"]:
             if group_data["cluster"] == actual_cluster:
                 default_group_data = group_data
                 break
@@ -430,7 +435,7 @@ class ContextBuilder:
                 actual_cluster_urls = [ClusterUrlData(rpc=cluster_url_from_environment)]
             else:
                 actual_cluster_urls = [
-                    ClusterUrlData(rpc=MangoConstants["cluster_urls"][actual_cluster])
+                    ClusterUrlData(rpc=EntropyConstants["cluster_urls"][actual_cluster])
                 ]
 
         actual_skip_preflight: bool = skip_preflight
@@ -439,7 +444,7 @@ class ContextBuilder:
         )
 
         found_group_data: typing.Any = None
-        for group in MangoConstants["groups"]:
+        for group in EntropyConstants["groups"]:
             if (
                 group["cluster"] == actual_cluster
                 and group["name"].upper() == actual_group_name.upper()
@@ -450,7 +455,7 @@ class ContextBuilder:
             raise Exception(
                 f"Could not find group named '{actual_group_name}' in cluster '{actual_cluster}'."
             )
-        print("foundGroupData", found_group_data)
+        # print("foundGroupData", found_group_data)
         actual_group_address: PublicKey = (
             group_address
             or __public_key_or_none(os.environ.get("GROUP_ADDRESS"))
@@ -486,7 +491,7 @@ class ContextBuilder:
             #
             # The problems come when they decide to rename symbols, like they did with "ETH".
             #
-            # Mango uses "ETH" with a mint 2FPyTwcZLUg1MDrwsyoP4D6s1tM7hAkHYRjkNb5w6Pxk and for a long time
+            # Entropy uses "ETH" with a mint 2FPyTwcZLUg1MDrwsyoP4D6s1tM7hAkHYRjkNb5w6Pxk and for a long time
             # the SPL JSON file also used "ETH" with a mint of 2FPyTwcZLUg1MDrwsyoP4D6s1tM7hAkHYRjkNb5w6Pxk.
             #
             # Then the SPL JSON file was updated and the mint 2FPyTwcZLUg1MDrwsyoP4D6s1tM7hAkHYRjkNb5w6Pxk now
